@@ -29,7 +29,7 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include "algorithms/StatFactory.h"
 
 namespace crule{
-  enum CRULE_TYPE {overwrite=0, maxndvi=1, maxband=2, minband=3, validband=4, mean=5, mode=6, median=7,sum=8,minallbands=9,maxallbands=10};
+  enum CRULE_TYPE {overwrite=0, maxndvi=1, maxband=2, minband=3, validband=4, mean=5, mode=6, median=7,sum=8,minallbands=9,maxallbands=10,stdev=11};
 }
 
 using namespace std;
@@ -46,24 +46,24 @@ int main(int argc, char *argv[])
   Optionpk<double>  uly_opt("uly", "uly", "Upper left y value bounding box", 0.0);
   Optionpk<double>  lrx_opt("lrx", "lrx", "Lower right x value bounding box", 0.0);
   Optionpk<double>  lry_opt("lry", "lry", "Lower right y value bounding box", 0.0);
-  Optionpk<string> crule_opt("cr", "crule", "Composite rule (overwrite, maxndvi, maxband, minband, mean, mode (only for byte images), median, sum, maxallbands, minallbands", "overwrite");
+  Optionpk<string> crule_opt("cr", "crule", "Composite rule (overwrite, maxndvi, maxband, minband, mean, mode (only for byte images), median, sum, maxallbands, minallbands, stdev", "overwrite");
   Optionpk<int> ruleBand_opt("cb", "cband", "band index used for the composite rule (e.g., for ndvi, use --cband=0 --cband=1 with 0 and 1 indices for red and nir band respectively", 0);
-  Optionpk<double> srcnodata_opt("srcnodata", "srcnodata", "invalid value for input image", 0);
-  Optionpk<int> bndnodata_opt("bndnodata", "bndnodata", "Bands in input image to check if pixel is valid (used for srcnodata, min and max options)", 0);
+  Optionpk<double> srcnodata_opt("srcnodata", "srcnodata", "invalid value(s) for input raster dataset");
+  Optionpk<int> bndnodata_opt("bndnodata", "bndnodata", "Band(s) in input image to check if pixel is valid (used for srcnodata, min and max options)", 0);
   Optionpk<double> minValue_opt("min", "min", "flag values smaller or equal to this value as invalid.");
   Optionpk<double> maxValue_opt("max", "max", "flag values larger or equal to this value as invalid.");
-  Optionpk<double>  dstnodata_opt("dstnodata", "dstnodata", "nodata value to put in output image if not valid or out of bounds.", 0);
+  Optionpk<double>  dstnodata_opt("dstnodata", "dstnodata", "nodata value to put in output raster dataset if not valid or out of bounds.", 0);
   Optionpk<string>  resample_opt("r", "resampling-method", "Resampling method (near: nearest neighbor, bilinear: bi-linear interpolation).", "near");
   Optionpk<string>  otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image", "");
   Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image");
   Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<string>  projection_opt("a_srs", "a_srs", "Override the spatial reference for the output file (leave blank to copy from input file, use epsg:3035 to use European projection and force to European grid");
-  Optionpk<bool> file_opt("file", "file", "write number of observations for each pixels as additional layer in composite", false);
+  Optionpk<short> file_opt("file", "file", "write number of observations (1) or sequence nr of selected file (2) for each pixels as additional layer in composite", 0);
   Optionpk<short> weight_opt("w", "weight", "Weights (type: short) for the composite, use one weight for each input file in same order as input files are provided). Use value 1 for equal weights.", 1);
   Optionpk<short> class_opt("c", "class", "classes for multi-band output image: each band represents the number of observations for one specific class. Use value 0 for no multi-band output image.", 0);
   Optionpk<string>  colorTable_opt("ct", "ct", "color table file with 5 columns: id R G B ALFA (0: transparent, 255: solid)");
   Optionpk<string>  description_opt("d", "description", "Set image description");
-  Optionpk<bool>  verbose_opt("v", "verbose", "verbose", false,2);
+  Optionpk<short>  verbose_opt("v", "verbose", "verbose", 0,2);
 
   file_opt.setHide(1);
   weight_opt.setHide(1);
@@ -130,9 +130,12 @@ int main(int argc, char *argv[])
   cruleMap["sum"]=crule::sum;
   cruleMap["maxallbands"]=crule::maxallbands;
   cruleMap["minallbands"]=crule::minallbands;
+  cruleMap["stdev"]=crule::stdev;
 
-  while(srcnodata_opt.size()<bndnodata_opt.size())
-    srcnodata_opt.push_back(srcnodata_opt[0]);
+  if(srcnodata_opt.size()){
+    while(srcnodata_opt.size()<bndnodata_opt.size())
+      srcnodata_opt.push_back(srcnodata_opt[0]);
+  }
   while(bndnodata_opt.size()<srcnodata_opt.size())
     bndnodata_opt.push_back(bndnodata_opt[0]);
   if(minValue_opt.size()){
@@ -273,6 +276,9 @@ int main(int argc, char *argv[])
         case(crule::median):
           cout << "Composite rule: median" << endl;
           break;
+        case(crule::stdev):
+          cout << "Composite rule: stdev" << endl;
+          break;
         case(crule::sum):
           cout << "Composite rule: sum" << endl;
           break;
@@ -477,7 +483,12 @@ int main(int argc, char *argv[])
     Vector2d< vector<double> > storeBuffer;
     vector<bool> writeValid(ncol);
 
-    if(cruleMap[crule_opt[0]]==crule::mean||cruleMap[crule_opt[0]]==crule::median||cruleMap[crule_opt[0]]==crule::sum||cruleMap[crule_opt[0]]==crule::minallbands||cruleMap[crule_opt[0]]==crule::maxallbands)//mean, median, (weighted) sum value, minallbands, maxallbands
+    if(cruleMap[crule_opt[0]]==crule::mean ||
+       cruleMap[crule_opt[0]]==crule::median ||
+       cruleMap[crule_opt[0]]==crule::sum ||
+       cruleMap[crule_opt[0]]==crule::minallbands ||
+       cruleMap[crule_opt[0]]==crule::maxallbands ||
+       cruleMap[crule_opt[0]]==crule::stdev)
       storeBuffer.resize(nband,ncol);
     for(int icol=0;icol<imgWriter.nrOfCol();++icol){
       writeValid[icol]=false;
@@ -614,6 +625,8 @@ int main(int argc, char *argv[])
           break;
 	}
 	if(readValid){
+	  if(file_opt[0]==1)
+	    ++fileBuffer[ib];
           if(writeValid[ib]){
             int iband=0;
 	    switch(cruleMap[crule_opt[0]]){
@@ -645,8 +658,8 @@ int main(int argc, char *argv[])
                     val_new=(readCol-0.5-lowerCol)*readBuffer[iband][upperCol-startCol]+(1-readCol+0.5+lowerCol)*readBuffer[iband][lowerCol-startCol];
                     writeBuffer[iband][ib]=val_new;
                   }
-                  fileBuffer[ib]=ifile;
-                  // ++fileBuffer[ib];
+		  if(file_opt[0]>1)
+		    fileBuffer[ib]=ifile;
                 }
                 break;
               default:
@@ -660,8 +673,8 @@ int main(int argc, char *argv[])
                     val_new=readBuffer[iband][readCol-startCol];
                     writeBuffer[iband][ib]=val_new;
                   }
-                  fileBuffer[ib]=ifile;
-                  // ++fileBuffer[ib];
+		  if(file_opt[0]>1)
+		    fileBuffer[ib]=ifile;
                 }
                 break;
               }
@@ -689,8 +702,8 @@ int main(int argc, char *argv[])
                     val_new*=weight_opt[ifile];
                     writeBuffer[iband][ib]=val_new;
                   }
-                  // fileBuffer[ib]=ifile;
-                  ++fileBuffer[ib];
+		  if(file_opt[0]>1)
+		    fileBuffer[ib]=ifile;
                 }
                 break;
               default:
@@ -703,8 +716,8 @@ int main(int argc, char *argv[])
                     val_new*=weight_opt[ifile];
                     writeBuffer[iband][ib]=val_new;
                   }
-                  // fileBuffer[ib]=ifile;
-                  ++fileBuffer[ib];
+		  if(file_opt[0]>1)
+		    fileBuffer[ib]=ifile;
                 }
                 break;
               }
@@ -740,6 +753,7 @@ int main(int argc, char *argv[])
 	    case(crule::sum)://sum value
 	    case(crule::minallbands)://minimum for each and every band
 	    case(crule::maxallbands)://maximum for each and every band
+	    case(crule::stdev)://maximum for each and every band
               switch(theResample){
               case(BILINEAR):
                 lowerCol=readCol-0.5;
@@ -768,7 +782,8 @@ int main(int argc, char *argv[])
                 }
                 break;
               }
-              ++fileBuffer[ib];
+	    if(file_opt[0]>1)
+	      fileBuffer[ib]=ifile;
 	      break;
 	    case(crule::overwrite):
 	    default:
@@ -797,8 +812,8 @@ int main(int argc, char *argv[])
                 }
                 break;
               }
-            // fileBuffer[ib]=ifile;
-            ++fileBuffer[ib];
+	    if(file_opt[0]>1)
+	      fileBuffer[ib]=ifile;
             break;
 	    }
 	  }
@@ -811,6 +826,7 @@ int main(int argc, char *argv[])
             case(crule::sum):
             case(crule::minallbands):
             case(crule::maxallbands):
+            case(crule::stdev):
               switch(theResample){
               case(BILINEAR):
                 lowerCol=readCol-0.5;
@@ -836,8 +852,9 @@ int main(int argc, char *argv[])
                 }
                 break;
               }
-              ++fileBuffer[ib];
-              break;
+	    if(file_opt[0]>1)
+	      fileBuffer[ib]=ifile;
+	    break;
             case(crule::mode):
               switch(theResample){
               case(BILINEAR):
@@ -891,8 +908,8 @@ int main(int argc, char *argv[])
                 }
                 break;
               }
-              // fileBuffer[ib]=ifile;
-              ++fileBuffer[ib];
+	      if(file_opt[0]>1)
+		fileBuffer[ib]=ifile;
               break;
             }
           }
@@ -920,7 +937,8 @@ int main(int argc, char *argv[])
           vector<short>::iterator maxit=maxBuffer[icol].begin();
           maxit=stat.mymax(maxBuffer[icol],maxBuffer[icol].begin(),maxBuffer[icol].end());
           writeBuffer[0][icol]=distance(maxBuffer[icol].begin(),maxit);
-          fileBuffer[icol]=*(maxit);
+	  if(file_opt[0]>1)
+	    fileBuffer[icol]=*(maxit);
         }
         try{
           imgWriter.writeData(writeBuffer[0],GDT_Float64,irow,0);
@@ -938,41 +956,48 @@ int main(int argc, char *argv[])
         // assert(writeBuffer[bands[iband]].size()==imgWriter.nrOfCol());
         assert(writeBuffer[iband].size()==imgWriter.nrOfCol());
         for(int icol=0;icol<imgWriter.nrOfCol();++icol){
-          switch(cruleMap[crule_opt[0]]){
-          case(crule::mean):
-            assert(storeBuffer[bands[iband]][icol].size()==fileBuffer[icol]);
-            if(storeBuffer[bands[iband]][icol].size())
-              writeBuffer[iband][icol]=stat.mean(storeBuffer[bands[iband]][icol]);
-            break;
-          case(crule::median):
-            assert(storeBuffer[bands[iband]][icol].size()==fileBuffer[icol]);
-            if(storeBuffer[bands[iband]][icol].size())
-              writeBuffer[iband][icol]=stat.median(storeBuffer[bands[iband]][icol]);
-            break;
-          case(crule::sum)://sum
-            assert(storeBuffer[bands[iband]][icol].size()==fileBuffer[icol]);
-            if(storeBuffer[bands[iband]][icol].size())
-              writeBuffer[iband][icol]=stat.sum(storeBuffer[bands[iband]][icol]);
-            break;
-          case(crule::minallbands):
-            assert(storeBuffer[bands[iband]][icol].size()==fileBuffer[icol]);
-            if(storeBuffer[bands[iband]][icol].size())
-              writeBuffer[iband][icol]=stat.mymin(storeBuffer[bands[iband]][icol]);
-            break;
-          case(crule::maxallbands):
-            assert(storeBuffer[bands[iband]][icol].size()==fileBuffer[icol]);
-            if(storeBuffer[bands[iband]][icol].size())
-              writeBuffer[iband][icol]=stat.mymax(storeBuffer[bands[iband]][icol]);
-            break;
-          default:
-            break;
-          }
+	  try{
+	    switch(cruleMap[crule_opt[0]]){
+	    case(crule::mean):
+	      // writeBuffer[iband][icol]=stat.mean(storeBuffer[bands[iband]][icol]);
+	      writeBuffer[iband][icol]=stat.mean(storeBuffer[iband][icol]);
+	      break;
+	    case(crule::median):
+	      // writeBuffer[iband][icol]=stat.median(storeBuffer[bands[iband]][icol]);
+	      writeBuffer[iband][icol]=stat.median(storeBuffer[iband][icol]);
+	      break;
+	    case(crule::sum):
+	      // writeBuffer[iband][icol]=stat.sum(storeBuffer[bands[iband]][icol]);
+	      writeBuffer[iband][icol]=stat.sum(storeBuffer[iband][icol]);
+	      break;
+	    case(crule::minallbands):
+	      // writeBuffer[iband][icol]=stat.mymin(storeBuffer[bands[iband]][icol]);
+	      writeBuffer[iband][icol]=stat.mymin(storeBuffer[iband][icol]);
+	      break;
+	    case(crule::maxallbands):
+	      // writeBuffer[iband][icol]=stat.mymax(storeBuffer[bands[iband]][icol]);
+	      writeBuffer[iband][icol]=stat.mymax(storeBuffer[iband][icol]);
+	      break;
+	    case(crule::stdev):
+	      // writeBuffer[iband][icol]=sqrt(stat.var(storeBuffer[bands[iband]][icol]));
+	      writeBuffer[iband][icol]=sqrt(stat.var(storeBuffer[iband][icol]));
+	      break;
+	    default:
+	      break;
+	    }
+	  }
+	  catch(string error){
+	    if(verbose_opt[0])
+	      cerr << error << endl;
+	    writeBuffer[iband][icol]=dstnodata_opt[0];
+	    continue;
+	  }
         }
         try{
           imgWriter.writeData(writeBuffer[iband],GDT_Float64,irow,iband);
         }
         catch(string error){
-          cerr << "error writing image file " << output_opt[0] << ": " << error << endl;
+          cerr << error << " in " << output_opt[0] << endl;
           throw;
         }
       }
@@ -981,7 +1006,7 @@ int main(int argc, char *argv[])
           imgWriter.writeData(fileBuffer,GDT_Int16,irow,bands.size());
         }
         catch(string error){
-          cerr << "error writing image file " << output_opt[0] << ": " << error << endl;
+          cerr << error << " in " << output_opt[0] << endl;
           throw;
         }
       }
