@@ -166,8 +166,8 @@ int main(int argc, char *argv[])
       extentReader.close();
     }
   }
-     double uli,ulj,lri,lrj;//image coordinates
-     double magicX=1,magicY=1;
+  double uli,ulj,lri,lrj;//image coordinates
+  double magicX=1,magicY=1;
   if(ulx_opt[0]>=lrx_opt[0]){//default bounding box: no cropping
     uli=0;
     lri=imgReader.nrOfCol()-1;
@@ -178,17 +178,15 @@ int main(int argc, char *argv[])
     imgReader.getBoundingBox(cropulx,cropuly,croplrx,croplry);
     imgReader.geo2image(cropulx+(magicX-1.0)*imgReader.getDeltaX(),cropuly-(magicY-1.0)*imgReader.getDeltaY(),uli,ulj);
     imgReader.geo2image(croplrx+(magicX-2.0)*imgReader.getDeltaX(),croplry-(magicY-2.0)*imgReader.getDeltaY(),lri,lrj);
-    ncropcol=ceil((croplrx-cropulx)/dx);
-    ncroprow=ceil((cropuly-croplry)/dy);
-    ncropcol=ceil((croplrx-cropulx)/dx);
-    ncroprow=ceil((cropuly-croplry)/dy);
+    ncropcol=abs(static_cast<int>(ceil((croplrx-cropulx)/dx)));
+    ncroprow=abs(static_cast<int>(ceil((cropuly-croplry)/dy)));
   }
   else{
     imgReader.geo2image(cropulx+(magicX-1.0)*imgReader.getDeltaX(),cropuly-(magicY-1.0)*imgReader.getDeltaY(),uli,ulj);
     imgReader.geo2image(croplrx+(magicX-2.0)*imgReader.getDeltaX(),croplry-(magicY-2.0)*imgReader.getDeltaY(),lri,lrj);
     
-    ncropcol=ceil((croplrx-cropulx)/dx);
-    ncroprow=ceil((cropuly-croplry)/dy);
+    ncropcol=abs(static_cast<int>(ceil((croplrx-cropulx)/dx)));
+    ncroprow=abs(static_cast<int>(ceil((cropuly-croplry)/dy)));
     uli=floor(uli);
     ulj=floor(ulj);
     lri=floor(lri);
